==> pulsar-client-all-3.2.2.3-sources.jar: org/apache/pulsar/client/admin/internal/http/AsyncHttpConnectorProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.admin.internal.http;

import org.apache.pulsar.shade.javax.ws.rs.client.Client;
import org.apache.pulsar.shade.javax.ws.rs.core.Configuration;
import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
import org.apache.pulsar.shade.org.glassfish.jersey.client.spi.Connector;
import org.apache.pulsar.shade.org.glassfish.jersey.client.spi.ConnectorProvider;

/**
 * Admin specific Jersey client connector provider.
 */
public class AsyncHttpConnectorProvider implements ConnectorProvider {

    private final ClientConfigurationData conf;
    private Connector connector;
    private final int autoCertRefreshTimeSeconds;

    public AsyncHttpConnectorProvider(ClientConfigurationData conf, int autoCertRefreshTimeSeconds) {
        this.conf = conf;
        this.autoCertRefreshTimeSeconds = autoCertRefreshTimeSeconds;
    }

    @Override
    public Connector getConnector(Client client, Configuration runtimeConfig) {
        if (connector == null) {
            connector = new AsyncHttpConnector(client, conf, autoCertRefreshTimeSeconds);
        }
        return connector;
    }


    public AsyncHttpConnector getConnector(int connectTimeoutMs, int readTimeoutMs, int requestTimeoutMs,
            int autoCertRefreshTimeSeconds) {
        return new AsyncHttpConnector(connectTimeoutMs, readTimeoutMs, requestTimeoutMs, autoCertRefreshTimeSeconds,
                conf);
    }
}

==> pulsar-client-all-4.0.5-sources.jar: org/apache/pulsar/client/admin/internal/http/AsyncHttpConnectorProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.admin.internal.http;

import org.apache.pulsar.shade.javax.ws.rs.client.Client;
import org.apache.pulsar.shade.javax.ws.rs.core.Configuration;
import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
import org.apache.pulsar.shade.org.glassfish.jersey.client.spi.Connector;
import org.apache.pulsar.shade.org.glassfish.jersey.client.spi.ConnectorProvider;

/**
 * Admin specific Jersey client connector provider.
 */
public class AsyncHttpConnectorProvider implements ConnectorProvider {

    private final ClientConfigurationData conf;
    private Connector connector;
    private final int autoCertRefreshTimeSeconds;
    private final boolean acceptGzipCompression;

    public AsyncHttpConnectorProvider(ClientConfigurationData conf, int autoCertRefreshTimeSeconds,
                                      boolean acceptGzipCompression) {
        this.conf = conf;
        this.autoCertRefreshTimeSeconds = autoCertRefreshTimeSeconds;
        this.acceptGzipCompression = acceptGzipCompression;
    }

    @Override
    public Connector getConnector(Client client, Configuration runtimeConfig) {
        if (connector == null) {
            connector = new AsyncHttpConnector(client, conf, autoCertRefreshTimeSeconds, acceptGzipCompression);
        }
        return connector;
    }


    public AsyncHttpConnector getConnector(int connectTimeoutMs, int readTimeoutMs, int requestTimeoutMs,
            int autoCertRefreshTimeSeconds) {
        return new AsyncHttpConnector(connectTimeoutMs, readTimeoutMs, requestTimeoutMs, autoCertRefreshTimeSeconds,
                conf, acceptGzipCompression);
    }
}
